------------------------------------------------
--
-- list all the available metrics:
set pagesize 9999
select distinct metric_name from dba_hist_sysmetric_summary order by 1;
--
------------------------------------------------
--
-- list max and average values from the past 7 days for selected metrics on each of up to 4 nodes
-- if you are not running RAC, everything will show up as node 1
-- uncomment other lines in the WHERE clause to select other metrics
-- adjust the "24*7" in the WHERE clause to the number of hours of history you want displayed
--
set pagesize 9999
set linesize 1000 trimsp on
col timestamp       format a16     
col snap_id         format 999999  heading 'SNAPID'
col instance_number format 99      heading 'NODE'
col metric_name     format a30     heading 'METIC'
col minval          format 999.99
col maxval          format 999.99
col average         format 999.99
col node1           format a17     heading '   MAX1    AVE1'
col node2           format a17     heading '   MAX2    AVE2'
col node3           format a17     heading '   MAX3    AVE3'
col node4           format a17     heading '   MAX4    AVE4'
--
select to_char(begin_time,'YYYY-MM-DD HH24:MI') timestamp,snap_id,metric_name, 
  (select to_char(maxval,'9999.9')||'  '||to_char(average,'9999.9') from dba_hist_sysmetric_summary where instance_number=1 and metric_name=a.metric_name and snap_id=a.snap_id and dbid=a.dbid) node1, 
  (select to_char(maxval,'9999.9')||'  '||to_char(average,'9999.9') from dba_hist_sysmetric_summary where instance_number=2 and metric_name=a.metric_name and snap_id=a.snap_id and dbid=a.dbid) node2, 
  (select to_char(maxval,'9999.9')||'  '||to_char(average,'9999.9') from dba_hist_sysmetric_summary where instance_number=3 and metric_name=a.metric_name and snap_id=a.snap_id and dbid=a.dbid) node3, 
  (select to_char(maxval,'9999.9')||'  '||to_char(average,'9999.9') from dba_hist_sysmetric_summary where instance_number=4 and metric_name=a.metric_name and snap_id=a.snap_id and dbid=a.dbid) node4
from dba_hist_sysmetric_summary a
where instance_number=1 
and snap_id > ((select max(snap_id) from dba_hist_snapshot where dbid=a.dbid)-(24*7))
and metric_name in (
'Current Logons Count'
,'Host CPU Utilization (%)'
,'Database CPU Time Ratio'
,'Database Wait Time Ratio'
--,'Process Limit %'
--,'Logical Reads Per Sec'
--,'Network Traffic Volume Per Sec'
--,'Physical Read Bytes Per Sec'
--,'Physical Read IO Requests Per Sec'
--,'Physical Read Total Bytes Per Sec'
--,'Physical Read Total IO Requests Per Sec'
--,'Physical Reads Direct Per Sec'
--,'Physical Reads Per Sec'
--,'Physical Write Bytes Per Sec'
--,'Physical Write IO Requests Per Sec'
--,'Physical Write Total Bytes Per Sec'
--,'Physical Write Total IO Requests Per Sec'
--,'Physical Writes Direct Per Sec'
--,'Physical Writes Per Sec'
)
order by snap_id, metric_name;
--
------------------------------------------------
--
-- This version stacks all of the selected metrics for a given snapshot 
-- on the same line to facilitate graphing via Excel, etc.
--
set pagesize 9999
set linesize 1000 trimsp on
col dbname          format a10     heading 'DBNAME'
col timestamp       format a16     
col snap_id         format 999999  heading 'SNAPID'
col instance_number format 99      heading 'NODE'
col ses1            format 9999
col ses2            format 9999
col ses3            format 9999
col ses4            format 9999
col cpu1            format 9999
col cpu2            format 9999
col cpu3            format 9999
col cpu4            format 9999
col dbwait1         format 9999
col dbwait2         format 9999
col dbwait3         format 9999
col dbwait4         format 9999
col dbcpu1          format 9999
col dbcpu2          format 9999
col dbcpu3          format 9999
col dbcpu4          format 9999
--
select distinct b.value dbname, to_char(a.begin_time,'YYYY-MM-DD HH24:MI') timestamp,a.snap_id
  ,(select average from dba_hist_sysmetric_summary where instance_number=1 and metric_name='Current Logons Count'     and snap_id=a.snap_id and dbid=a.dbid) ses1
  ,(select average from dba_hist_sysmetric_summary where instance_number=2 and metric_name='Current Logons Count'     and snap_id=a.snap_id and dbid=a.dbid) ses2
  ,(select average from dba_hist_sysmetric_summary where instance_number=3 and metric_name='Current Logons Count'     and snap_id=a.snap_id and dbid=a.dbid) ses3
  ,(select average from dba_hist_sysmetric_summary where instance_number=4 and metric_name='Current Logons Count'     and snap_id=a.snap_id and dbid=a.dbid) ses4
  ,(select average from dba_hist_sysmetric_summary where instance_number=1 and metric_name='Host CPU Utilization (%)' and snap_id=a.snap_id and dbid=a.dbid) cpu1
  ,(select average from dba_hist_sysmetric_summary where instance_number=2 and metric_name='Host CPU Utilization (%)' and snap_id=a.snap_id and dbid=a.dbid) cpu2
  ,(select average from dba_hist_sysmetric_summary where instance_number=3 and metric_name='Host CPU Utilization (%)' and snap_id=a.snap_id and dbid=a.dbid) cpu3
  ,(select average from dba_hist_sysmetric_summary where instance_number=4 and metric_name='Host CPU Utilization (%)' and snap_id=a.snap_id and dbid=a.dbid) cpu4
  ,(select average from dba_hist_sysmetric_summary where instance_number=1 and metric_name='Database Wait Time Ratio' and snap_id=a.snap_id and dbid=a.dbid) dbwait1
  ,(select average from dba_hist_sysmetric_summary where instance_number=2 and metric_name='Database Wait Time Ratio' and snap_id=a.snap_id and dbid=a.dbid) dbwait2
  ,(select average from dba_hist_sysmetric_summary where instance_number=3 and metric_name='Database Wait Time Ratio' and snap_id=a.snap_id and dbid=a.dbid) dbwait3
  ,(select average from dba_hist_sysmetric_summary where instance_number=4 and metric_name='Database Wait Time Ratio' and snap_id=a.snap_id and dbid=a.dbid) dbwait4
  ,(select average from dba_hist_sysmetric_summary where instance_number=1 and metric_name='Database CPU Time Ratio'  and snap_id=a.snap_id and dbid=a.dbid) dbcpu1
  ,(select average from dba_hist_sysmetric_summary where instance_number=2 and metric_name='Database CPU Time Ratio'  and snap_id=a.snap_id and dbid=a.dbid) dbcpu2
  ,(select average from dba_hist_sysmetric_summary where instance_number=3 and metric_name='Database CPU Time Ratio'  and snap_id=a.snap_id and dbid=a.dbid) dbcpu3
  ,(select average from dba_hist_sysmetric_summary where instance_number=4 and metric_name='Database CPU Time Ratio'  and snap_id=a.snap_id and dbid=a.dbid) dbcpu4 
from dba_hist_sysmetric_summary a,dba_hist_parameter b
where a.instance_number=1 
and a.snap_id=b.snap_id
and a.dbid=b.dbid
and b.parameter_name='db_name'
and a.snap_id > ((select max(snap_id) from dba_hist_snapshot where dbid=a.dbid)-(24*30))
order by a.snap_id;
--
------------------------------------------------










